"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Actions and events related to the inspected page belong to the page domain.
https://chromedevtools.github.io/devtools-protocol/tot/Page/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    DOM,
    Network,
    Page,
    Runtime,
)
from cdpkit.protocol.base import CDPEvent


class DomContentEventFired(CDPEvent):

    timestamp: Network.MonotonicTime


class FileChooserOpened(CDPEvent):
    """ Emitted only when `page.interceptFileChooser` is enabled. """

    frameId: Page.FrameId | None = None  # experimental deprecated
    mode: Literal['selectSingle', 'selectMultiple']  # deprecated
    backendNodeId: DOM.BackendNodeId | None = None  # experimental deprecated


class FrameAttached(CDPEvent):
    """ Fired when frame has been attached to its parent. """

    frameId: Page.FrameId  # deprecated
    parentFrameId: Page.FrameId  # deprecated
    stack: Runtime.StackTrace | None = None  # deprecated


class FrameClearedScheduledNavigation(CDPEvent):
    """ Fired when frame no longer has a scheduled navigation. """

    frameId: Page.FrameId  # deprecated


class FrameDetached(CDPEvent):
    """ Fired when frame has been detached from its parent. """

    frameId: Page.FrameId  # deprecated
    reason: Literal['remove', 'swap'] | None = None  # experimental


class FrameSubtreeWillBeDetached(CDPEvent):
    """ Fired before frame subtree is detached. Emitted before any frame of the
    subtree is actually detached. """

    frameId: Page.FrameId  # deprecated


class FrameNavigated(CDPEvent):
    """ Fired once navigation of the frame has completed. Frame is now associated with the new loader. """

    frame: Page.Frame  # deprecated
    type: Page.NavigationType | None = None  # experimental


class DocumentOpened(CDPEvent):
    """ Fired when opening document to write to. """

    frame: Page.Frame  # deprecated


class FrameResized(CDPEvent):

    ...


class FrameStartedNavigating(CDPEvent):
    """ Fired when a navigation starts. This event is fired for both
    renderer-initiated and browser-initiated navigations. For renderer-initiated
    navigations, the event is fired after `frameRequestedNavigation`.
    Navigation may still be cancelled after the event is issued. Multiple events
    can be fired for a single navigation, for example, when a same-document
    navigation becomes a cross-document navigation (such as in the case of a
    frameset). """

    frameId: Page.FrameId  # deprecated
    url: str  # deprecated
    loaderId: Network.LoaderId  # deprecated
    navigationType: Literal['reload', 'reloadBypassingCache', 'restore', 'restoreWithPost', 'historySameDocument', 'historyDifferentDocument', 'sameDocument', 'differentDocument']


class FrameRequestedNavigation(CDPEvent):
    """ Fired when a renderer-initiated navigation is requested.
    Navigation may still be cancelled after the event is issued. """

    frameId: Page.FrameId  # deprecated
    reason: Page.ClientNavigationReason  # deprecated
    url: str  # deprecated
    disposition: Page.ClientNavigationDisposition  # deprecated


class FrameScheduledNavigation(CDPEvent):
    """ Fired when frame schedules a potential navigation. """

    frameId: Page.FrameId  # deprecated
    delay: float  # deprecated
    reason: Page.ClientNavigationReason  # deprecated
    url: str  # deprecated


class FrameStartedLoading(CDPEvent):
    """ Fired when frame has started loading. """

    frameId: Page.FrameId  # deprecated


class FrameStoppedLoading(CDPEvent):
    """ Fired when frame has stopped loading. """

    frameId: Page.FrameId  # deprecated


class DownloadWillBegin(CDPEvent):
    """ Fired when page is about to start a download.
    Deprecated. Use Browser.downloadWillBegin instead. """

    frameId: Page.FrameId  # deprecated
    guid: str  # deprecated
    url: str  # deprecated
    suggestedFilename: str  # deprecated


class DownloadProgress(CDPEvent):
    """ Fired when download makes progress. Last call has |done| == true.
    Deprecated. Use Browser.downloadProgress instead. """

    guid: str  # deprecated
    totalBytes: float  # deprecated
    receivedBytes: float  # deprecated
    state: Literal['inProgress', 'completed', 'canceled']  # deprecated


class InterstitialHidden(CDPEvent):
    """ Fired when interstitial page was hidden """

    ...


class InterstitialShown(CDPEvent):
    """ Fired when interstitial page was shown """

    ...


class JavascriptDialogClosed(CDPEvent):
    """ Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been
    closed. """

    frameId: Page.FrameId | None = None  # experimental deprecated
    result: bool  # deprecated
    userInput: str  # deprecated


class JavascriptDialogOpening(CDPEvent):
    """ Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to
    open. """

    url: str  # deprecated
    frameId: Page.FrameId | None = None  # experimental deprecated
    message: str  # deprecated
    type: Page.DialogType  # deprecated
    hasBrowserHandler: bool  # deprecated
    defaultPrompt: str | None = None  # deprecated


class LifecycleEvent(CDPEvent):
    """ Fired for lifecycle events (navigation, load, paint, etc) in the current
    target (including local frames). """

    frameId: Page.FrameId  # deprecated
    loaderId: Network.LoaderId  # deprecated
    name: str
    timestamp: Network.MonotonicTime


class BackForwardCacheNotUsed(CDPEvent):
    """ Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do
    not assume any ordering with the Page.frameNavigated event. This event is fired only for
    main-frame history navigation where the document changes (non-same-document navigations),
    when bfcache navigation fails. """

    loaderId: Network.LoaderId  # deprecated
    frameId: Page.FrameId  # deprecated
    notRestoredExplanations: list[Page.BackForwardCacheNotRestoredExplanation]  # deprecated
    notRestoredExplanationsTree: Page.BackForwardCacheNotRestoredExplanationTree | None = None  # deprecated


class LoadEventFired(CDPEvent):

    timestamp: Network.MonotonicTime


class NavigatedWithinDocument(CDPEvent):
    """ Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation. """

    frameId: Page.FrameId  # deprecated
    url: str  # deprecated
    navigationType: Literal['fragment', 'historyApi', 'other']  # deprecated


class ScreencastFrame(CDPEvent):
    """ Compressed image data requested by the `startScreencast`. """

    data: str  # deprecated
    metadata: Page.ScreencastFrameMetadata  # deprecated
    sessionId: int  # deprecated


class ScreencastVisibilityChanged(CDPEvent):
    """ Fired when the page with currently enabled screencast was shown or hidden `. """

    visible: bool  # deprecated


class WindowOpen(CDPEvent):
    """ Fired when a new window is going to be opened, via window.open(), link click, form submission,
    etc. """

    url: str  # deprecated
    windowName: str  # deprecated
    windowFeatures: list[str]  # deprecated
    userGesture: bool  # deprecated


class CompilationCacheProduced(CDPEvent):
    """ Issued for every compilation cache generated. Is only available
    if Page.setGenerateCompilationCache is enabled. """

    url: str
    data: str  # deprecated
